argus_cli — Argus-Toolbelt 1.0 documentation

# argus_cli

- Argus CLI Documentation
  - Settings file
  - Subpackages
    - argus_cli.helpers package
      - Submodules
      - argus_cli.helpers.collections module
      - argus_cli.helpers.formatting module
      - argus_cli.helpers.log module
      - Module contents
  - Submodules
  - argus_cli.arguments module
  - argus_cli.cli module
  - argus_cli.plugin module
  - argus_cli.settings module
  - Module contents